@@ -6,15 +6,7 @@ import os
 FORMAT = '[%(levelname)-7s] [%(name)-35s] - %(message)s' 
 logging.basicConfig(level=logging.INFO, format=FORMAT)
 
-CAMELOT_MAIN_DIRECTORY = os.path.dirname(inspect.getabsfile(camelot))
-CAMELOT_LIB_DIRECTORY = os.path.join(CAMELOT_MAIN_DIRECTORY, 'librairies')
-CAMELOT_ART_DIRECTORY = os.path.join(CAMELOT_MAIN_DIRECTORY, 'art')
-
-CAMELOT_TEMPLATES_DIRECTORY = os.path.join(CAMELOT_MAIN_DIRECTORY,
-                                           'view', 'templates')
-CAMELOT_ATTACHMENTS = 'G:\Data\Attachments'
 CAMELOT_MEDIA_ROOT = os.path.join(os.path.dirname(__file__), 'media')
-
 ENGINE = lambda:'sqlite:///videostore.sqlite'
 
 #logging.getLogger('sqlalchemy.engine').setLevel(logging.DEBUG)
